function imageAlignment = getROIs_IA(Irotated,epiRotated,imageAlignment,chamberOffset,showFigure)

    % Define and Show ROIs  -  !! image inverted -> plot(xx,yy) / imageTest(yy,xx)
    
    [Ni,Mi] = size(Irotated);
    
    x_shift = imageAlignment.x_shift;
    y_shift = imageAlignment.y_shift;
    x_center = imageAlignment.x_center;
    y_center = imageAlignment.y_center;
    ybegin = imageAlignment.y_begin;
    yend = imageAlignment.y_end;
        
    %ROI1 -> left chamber  //  rectangle('position',[x y w h])
    w1 = x_center+x_shift+chamberOffset.xL;
    h1 = y_center+y_shift+chamberOffset.yL;
    x1 = 1;
    y1 = 1;
    if y1+h1 > Ni
        h1 = Ni-y1;
    end
    if showFigure == 1
        imshow(imadjust(Irotated));
        rectangle('position',[x1 y1 w1 h1],'EdgeColor','y');
        text(x1+10,y1+10,'ROI1','FontSize',6,'Color','y');
    end
    meanDia1 = mean2(Irotated(y1:y1+h1,x1:x1+w1));
    meanEpi1 = mean2(epiRotated(y1:y1+h1,x1:x1+w1));

    %ROI2 -> right chamber
    w2 = Mi-(x_center+x_shift+chamberOffset.xR);
    h2 = y_center+y_shift+chamberOffset.yR;
    x2 = x_center+x_shift+chamberOffset.xR;
    y2 = 1;
    if y2+h2 > Ni
        h2 = Ni-y2;
    end
    if showFigure == 1
        rectangle('position',[x2 y2 w2 h2],'EdgeColor','y');
        text(x2+10,y2+10,'ROI2','FontSize',6,'Color','y');
    end
    meanDia2 = mean2(Irotated(y2:y2+h2,x2:x2+w2));
    meanEpi2 = mean2(epiRotated(y2:y2+h2,x2:x2+w2));

    %ROI3 -> chamber wall top
    w3 = 30;
    h3 = 300;
    x3 = x_center+x_shift-w3/2;
    y3 = ybegin;
    if yend - ybegin > h3
        if showFigure == 1
            rectangle('position',[x3 y3 w3 h3],'EdgeColor','y');
            text(x3+5,y3+10,'ROI3','FontSize',6,'Color','y');
        end
        meanDia3 = mean2(Irotated(y3:y3+h3,x3:x3+w3));
        meanEpi3 = mean2(epiRotated(y3:y3+h3,x3:x3+w3));
    end

    %ROI4 -> chamber wall bottom
    w4= 30;
    h4 = 300;
    x4 = x_center+x_shift-w4/2;
    y4 = y_center+y_shift+chamberOffset.yL-h4;
    if y4+h4 > Ni
        h4 = Ni-y4;
    end
    if showFigure == 1
        rectangle('position',[x4 y4 w4 h4],'EdgeColor','y');
        text(x4+5,y4+10,'ROI4','FontSize',6,'Color','y');
    end
    meanDia4 = mean2(Irotated(y4:y4+h4,x4:x4+w4));
    meanEpi4 = mean2(epiRotated(y4:y4+h4,x4:x4+w4));

    %ROI5 -> below both chamber
    w5= 100;
    x5 = x_center+x_shift-w5/2;
    y5 = y_center+y_shift+chamberOffset.yL+50;
    if y5 + 100 <= Ni
        h5 = 100;
        if showFigure == 1
            rectangle('position',[x5 y5 w5 h5],'EdgeColor','y');
            text(x5+10,y5+10,'ROI5','FontSize',6,'Color','y');
        end
        meanDia5 = mean2(Irotated(y5:y5+h5,x5:x5+w5));
        meanEpi5 = mean2(epiRotated(y5:y5+h5,x5:x5+w5));
    elseif y5 + 20 < Ni
        h5 = Ni - y5;
        if showFigure == 1
            rectangle('position',[x5 y5 w5 h5],'EdgeColor','y');
            text(x5+10,y5+10,'ROI5','FontSize',6,'Color','y');
        end
        meanDia5 = mean2(Irotated(y5:y5+h5,x5:x5+w5));
        meanEpi5 = mean2(epiRotated(y5:y5+h5,x5:x5+w5));
    else
        h5 = 0;
        meanDia5 = 0;
        meanEpi5 = 0;
    end
    
    % Save ROI data
    imageAlignment.ROI{1}.x = x1;
    imageAlignment.ROI{1}.y = y1;
    imageAlignment.ROI{1}.w = w1;
    imageAlignment.ROI{1}.h = h1;
    imageAlignment.ROI{1}.meanDia = meanDia1;
    imageAlignment.ROI{1}.meanEpi = meanEpi1;
       
    imageAlignment.ROI{2}.x = x2;
    imageAlignment.ROI{2}.y = y2;
    imageAlignment.ROI{2}.w = w2;
    imageAlignment.ROI{2}.h = h2;
    imageAlignment.ROI{2}.meanDia = meanDia2;
    imageAlignment.ROI{2}.meanEpi = meanEpi2;
    
    imageAlignment.ROI{3}.x = x3;
    imageAlignment.ROI{3}.y = y3;
    imageAlignment.ROI{3}.w = w3;
    imageAlignment.ROI{3}.h = h3;
    imageAlignment.ROI{3}.meanDia = meanDia3;
    imageAlignment.ROI{3}.meanEpi = meanEpi3;
    
    imageAlignment.ROI{4}.x = x4;
    imageAlignment.ROI{4}.y = y4;
    imageAlignment.ROI{4}.w = w4;
    imageAlignment.ROI{4}.h = h4;
    imageAlignment.ROI{4}.meanDia = meanDia4;
    imageAlignment.ROI{4}.meanEpi = meanEpi4;
    
    imageAlignment.ROI{5}.x = x5;
    imageAlignment.ROI{5}.y = y5;
    imageAlignment.ROI{5}.w = w5;
    imageAlignment.ROI{5}.h = h5;
    imageAlignment.ROI{5}.meanDia = meanDia5;
    imageAlignment.ROI{5}.meanEpi = meanEpi5;
    
    
    
    