function [names, values] = ml_hullfeatures(imageproc)
% MB_HULLFEATURES - calculates features using the convex hull of IMAGE
% [NAMES, VALUES] = MB_HULLFEATURES(IMAGEPROC, IMAGEHULL) 
%     IMAGEPROC is the processed fluorescence image, IMAGEHULL is its binary 
%     convex hull.


BWimage = double(im2bw(imageproc));
imagehull = ml_imgconvhull(BWimage);

% Ahull = area of the convex hull.
Ahull = bwarea(imagehull);
hullfract = Ahull/length(find(imageproc));

% 'Shape factor' of the convex hull.
%    Phull = approximation to the hull perimeter.
Phull = bwarea(bwperim(imagehull));
hullshape = (Phull^2)/(4*pi*Ahull);

% Central moments of the convex hull
%
hull_mu00 = ml_imgcentmoments(imagehull,0,0) ;
hull_mu11 = ml_imgcentmoments(imagehull,1,1) ;
hull_mu02 = ml_imgcentmoments(imagehull,0,2) ;
hull_mu20 = ml_imgcentmoments(imagehull,2,0) ;

hull_semimajor = sqrt((2 * (hull_mu20 + hull_mu02 + sqrt((hull_mu20 - hull_mu02)^2 + 4 * hull_mu11^2)))/hull_mu00) ;
hull_semiminor = sqrt((2 * (hull_mu20 + hull_mu02 - sqrt((hull_mu20 - hull_mu02)^2 + 4 * hull_mu11^2)))/hull_mu00) ;
hull_eccentricity = sqrt(hull_semimajor^2 - hull_semiminor^2) / hull_semimajor;

names = {'convex_hull:fraction_of_overlap' 'convex_hull:shape_factor' 'convex_hull:eccentricity'} ;
values = [hullfract hullshape hull_eccentricity] ;
