function nd_AFsub_mcmc_fct(info,side,fid)

% MCMC calculation

% Input
expDirectory = info.expDirectory;
%expName = info.expName;
scAnalysisDir = info.scDir;
p = info.position;

% Plot options
showSummaryPlot = info.AFsub.showSummaryPlot;
showFramePlot = info.AFsub.showFramePlot;
N = info.AFsub.Nplot;
    
% FFT options
Ts = info.AFsub.Ts;
Tstart = info.AFsub.Tstart;

% MCMC options
Dx = @(mu) 10.^(0.6 * log10(mu) - 0.75); 
nsamples = info.AFsub.nsamples;
nstart = info.AFsub.nstart;
sigma = info.AFsub.sigma;

% yOrf
if side == 'L';
    sideNum = 2;
else
    sideNum = 1;
end
X = load(fullfile(expDirectory,'expData.mat'));
expData = X.expData;
 yOrf = expData{p,sideNum}.yORF;
 
% Directories
scMainDir = fullfile(expDirectory,scAnalysisDir);
%scDir = fullfile(scMainDir,sprintf('pos%d_%s',p,side));
scDataDir = fullfile(scMainDir,'scData');
scFileOut = dir(fullfile(scDataDir,sprintf('*_pos%d_%c.mat',p,side)));
X = load(fullfile(scDataDir,scFileOut.name));sc = X.sc;
clear X

T = numel(sc.minSub.frame);

% Output directories
summaryPlotDir = fullfile(scMainDir,'AFsubSummaryPlots'); mkdir(summaryPlotDir);
framePlotDir = fullfile(scMainDir,'AFsubFramePlots'); mkdir(framePlotDir);
dataDir = fullfile(scMainDir,'AFsubData'); mkdir(dataDir);

AFtype = 3;
% Load AF data
switch AFtype
    case 1
        load('AFnormal.mat','AFnormal');
        mAF = AFnormal.mAF;
        sAF = AFnormal.sAF;
        fAF = @(x) normpdf(x,mAF,sAF);
        fConv = @(x,param,dx) nd_gammaNormConv_pdf(x,param,[mAF sAF],dx);  
    case 2
        load('AFgamma.mat','AFgamma');
        kAF = AFgamma.kAF;
        tAF = AFgamma.tAF;
        mAF = kAF*tAF;
        sAF = sqrt(kAF*tAF^2);
        fAF = @(x) gampdf(x,kAF,tAF);
        fConv = @(x,param,dx) nd_gamma2Conv_pdf(x,param,[kAF tAF],dx);  
    case 3
        load('AFlogn.mat','AFlogn');
        muAF = AFlogn.mAF;
        sigmaAF = AFlogn.sAF;
        mAF = exp(muAF+sigmaAF^2/2);
        sAF = sqrt((exp(sigmaAF^2)-1)*exp(2*muAF+sigmaAF^2));
        fAF = @(x) lognpdf(x,muAF,sigmaAF);
        fConv = @(x,param,dx) nd_gammaLognConv_pdf(x,param,[muAF sigmaAF],dx);  
    otherwise
        return
end


for t=1:T

    idxZero = find(sc.minSub.frame(t).selected == 0);
    idxNaN = find(isnan(sc.minSub.frame(t).selected));
    if ~isempty(idxZero), fprintf(fid,'\t\tWarning: %d zero cells at frame %d\n',numel(idxZero),t); end
    if ~isempty(idxNaN), fprintf(fid,'\t\tWarning: %d NaN cells at frame %d\n',numel(idxNaN),t); end
    idx = setdiff(1:numel(sc.minSub.frame(t).selected),union(idxZero,idxNaN));
    sig = sc.minSub.frame(t).selected(idx);

    if numel(sig) ~= 0
        
        mSig = mean(sig);
        sSig = std(sig);


        %% 1. Methods of moments
        mMom = mSig-mAF;
        sMom = sSig-sAF;
        kMom = mMom^2/sMom^2;
        tMom = sMom^2/mMom;
        if mMom < 0 || sMom < 0
            kMom = NaN;
            tMom = NaN;
            momFlag = 0;
        else
            momFlag = 1;
        end


        %% 2. FFT convolution

        sMax = max(sig);
        vMax = 1.5*sMax;
        sample = Tstart:Ts:vMax;
        distAF = fAF(sample);

        if isnan(kMom)
            start = [1; 1];
        else
            start = [kMom; tMom];
        end
        tic;
        options = optimset('TolX',0.001,'MaxFunEvals',100000);
        [ktFFT,errorFFT,flagFFT] = fminsearch(@(param) nd_fftConvFit9(param,distAF,sig,Ts,Tstart),start,options);
        kFFT = ktFFT(1);
        tFFT = ktFFT(2);
        timeFFT = toc;


        %% 3. Numerical convolution (fminsearch and MCMC)

        dx = Dx(kFFT*tFFT);
        if 2*dx > min(sig)-dx, dx = (min(sig)-dx)/2; end
        
        f = @(param) sum(log(fConv(sig,param,dx)));  

        x0 = [kFFT tFFT];

        tic;
        [ktFit,logLFit,flagFit,outputFit] = fminsearch(@(param) -f(param) + sum(param<0) * 1e300 ,x0);
        logLFit = -logLFit;
        kFit = ktFit(1);
        tFit = ktFit(2);
        timeFit = toc;
        
        if nsamples == 0
            logLMCMC = NaN;
            kMCMC = NaN;
            ksMCMC = NaN;
            tMCMC = NaN;
            tsMCMC = NaN;
            mmMCMC = NaN;
            msMCMC = NaN;
            noisemMCMC = NaN;
            noisesMCMC = NaN;
            timeMCMC = NaN;
            accept = NaN;
        else
            x0 = [kFit tFit];
            tic;
            [paravec,probvec,accept] = nd_mcmc_log(x0,f,nsamples,sigma);
            logLMCMC = mean(probvec(nstart:end,:));
            mMCMC = mean(paravec(nstart:end,:));
            sMCMC = std(paravec(nstart:end,:));
            kMCMC = mMCMC(1);
            ksMCMC = sMCMC(1);
            tMCMC = mMCMC(2);
            tsMCMC = sMCMC(2);
            mmMCMC = mean(paravec(nstart:end,1).*paravec(nstart:end,2));
            msMCMC = std(paravec(nstart:end,1).*paravec(nstart:end,2));
            noisemMCMC = mean(1./paravec(nstart:end,1));
            noisesMCMC = std(1./paravec(nstart:end,1));
            timeMCMC = toc;
        end


        %% Save values

        sc.AFsub.mSig(t) = mSig;
        sc.AFsub.sSig(t) = sSig;
        sc.AFsub.nCell(t) = numel(sig);

        % Moments
        sc.AFsub.kMom(t) = kMom;
        sc.AFsub.tMom(t) = tMom;
        sc.AFsub.momFlag(t) = momFlag;

        % FFT
        sc.AFsub.kFFT(t) = kFFT;
        sc.AFsub.tFFT(t) = tFFT;
        sc.AFsub.Ts(t) = Ts;
        sc.AFsub.Tstart(t) = Tstart;
        sc.AFsub.errorFFT(t) = errorFFT;
        sc.AFsub.flagFFT(t) = flagFFT;
        sc.AFsub.timeFFT(t) = timeFFT;

        % Fit
        sc.AFsub.kFit(t) = kFit;
        sc.AFsub.tFit(t) = tFit;
        sc.AFsub.dx(t) = dx;
        sc.AFsub.flagFit(t) = flagFit;
        sc.AFsub.LogLFit(t) = logLFit;
        sc.AFsub.timeFit(t) = timeFit;

        % MCMC
        sc.AFsub.kMCMC(t) = kMCMC;
        sc.AFsub.tMCMC(t) = tMCMC;
        sc.AFsub.ksMCMC(t) = ksMCMC;
        sc.AFsub.tsMCMC(t) = tsMCMC;
        sc.AFsub.mmMCMC(t) = mmMCMC;
        sc.AFsub.msMCMC(t) = msMCMC;
        sc.AFsub.noisemMCMC(t) = noisemMCMC;
        sc.AFsub.noisesMCMC(t) = noisesMCMC;
        sc.AFsub.LogLMCMC(t) = logLMCMC;
        sc.AFsub.timeMCMC(t) = timeMCMC;
        sc.AFsub.nsamples(t) = nsamples;
        sc.AFsub.nstart(t) = nstart;
        sc.AFsub.sigma(t,:) = sigma;
        sc.AFsub.accept(t) = accept;

    else
        
         %% Save values
         
        sc.AFsub.mSig(t) = NaN;
        sc.AFsub.sSig(t) = NaN;
        sc.AFsub.nCell(t) = 0;

        % Moments
        sc.AFsub.kMom(t) = NaN;
        sc.AFsub.tMom(t) = NaN;
        sc.AFsub.momFlag(t) = NaN;

        % FFT
        sc.AFsub.kFFT(t) = NaN;
        sc.AFsub.tFFT(t) = NaN;
        sc.AFsub.Ts(t) = NaN;
        sc.AFsub.Tstart(t) = NaN;
        sc.AFsub.errorFFT(t) = NaN;
        sc.AFsub.flagFFT(t) = NaN;
        sc.AFsub.timeFFT(t) = NaN;

        % Fit
        sc.AFsub.kFit(t) = NaN;
        sc.AFsub.tFit(t) = NaN;
        sc.AFsub.dx(t) = NaN;
        sc.AFsub.flagFit(t) = NaN;
        sc.AFsub.LogLFit(t) = NaN;
        sc.AFsub.timeFit(t) = NaN;

        % MCMC
        sc.AFsub.kMCMC(t) = NaN;
        sc.AFsub.tMCMC(t) = NaN;
        sc.AFsub.ksMCMC(t) = NaN;
        sc.AFsub.tsMCMC(t) = NaN;
        sc.AFsub.mmMCMC(t) = NaN;
        sc.AFsub.msMCMC(t) = NaN;
        sc.AFsub.noisemMCMC(t) = NaN;
        sc.AFsub.noisesMCMC(t) = NaN;
        sc.AFsub.LogLMCMC(t) = NaN;
        sc.AFsub.timeMCMC(t) = NaN;
        sc.AFsub.nsamples(t) = NaN;
        sc.AFsub.nstart(t) = NaN;
        sc.AFsub.sigma(t,:) = NaN;
        sc.AFsub.accept(t) = NaN;
        
    end
        
    
    %% Plot comparison per time point
    if showFramePlot == 1
        figure(1), clf, hold on,

        x = 1:1.5*vMax;
        xNC = 5*dx:5*dx:vMax;
        Nbin = 25;
        [yHist, xHist] = hist(sig,Nbin);
        bar(xHist,yHist/sum(yHist*(mean(diff(xHist)))),'c','edgeColor','none');
        plot(x,fAF(x),'r','linewidth',1.5);
        
        % FFT
        plot(x,gampdf(x,kFFT,tFFT),'g','linewidth',1.5);
        zFFT = real(ifft(fft(fAF(x)).*fft(gampdf(x,kFFT,tFFT))));
        plot(x,zFFT,'b','linewidth',1.5);

        % fminsearch fit
        plot(x,gampdf(x,kFit,tFit),'g--','linewidth',1.5);
        zFit = fConv(xNC,[kFit tFit],dx);
        plot(xNC,zFit,'b--','linewidth',1.5);

        % MCMC
        if nsamples ~= 0
            plot(x,gampdf(x,kMCMC,tMCMC),'g:','linewidth',1.5);
            zMCMC = fConv(xNC,[kMCMC tMCMC],dx);
            plot(xNC,zMCMC,'b:','linewidth',1.5);
        end

        xlabel('Fluorescence (a.u)','fontsize',12);
        ylabel('Frequency','fontsize',12);
        set(gca,'linewidth',1.5,'fontsize',12);
        if nsamples == 0
            h = legend(sprintf('Signal (n=%d)',numel(sig)),sprintf('AF (m=%.2f, s=%.2f)',mAF,sAF),...
                sprintf('FFT_{GFP} (k=%.2f, t=%.2f)',kFFT,tFFT),sprintf('FFT_{sig} (error=%.2f)',errorFFT),...
                sprintf('Fit_{GFP} (k=%.2f, t=%.2f)',kFit,tFit),sprintf('Fit_{sig} (logL=%.2f)',logLFit));
        else
            h = legend(sprintf('Signal (n=%d)',numel(sig)),sprintf('AF (m=%.2f, s=%.2f)',mAF,sAF),...
                sprintf('FFT_{GFP} (k=%.2f, t=%.2f)',kFFT,tFFT),sprintf('FFT_{sig} (error=%.2f)',errorFFT),...
                sprintf('Fit_{GFP} (k=%.2f, t=%.2f)',kFit,tFit),sprintf('Fit_{sig} (logL=%.2f)',logLFit),...
                sprintf('MCMC_{GFP} (k=%.2f%s%.2f, t=%.2f%s%.2f)',kMCMC,char(177),ksMCMC,tMCMC,char(177),tsMCMC),sprintf('MCMC_{sig} (logL=%.2f)',logLMCMC));
        end
        set(h, 'Box', 'off');
        set(h, 'Color', 'none');
        set(h, 'fontsize',10);
        print(1,'-dpng',fullfile(framePlotDir,sprintf('AFsub_pos%d_%c_frame%d.png',p,side,t)));
    end
    
end

% Add-ons
sc.AFsub.condition = sc.minSub.condition;
sc.AFsub.siwtchTiming = sc.minSub.switchTiming;
sc.AFsub.timing = sc.minSub.timing;
sc.AFsub.xLabel = 'time (hours)';
sc.AFsub.yLabel = 'Protein distribution (a.u.)';
sc.AFsub.title = sprintf('AF sub distribution - %s',yOrf);
sc.AFsub.AFtype = AFtype;


%% Save data

save(fullfile(dataDir,sprintf('dataAFsub__pos%d_%c.mat',p,side)),'sc');


%% Plot summary plot for all time points
if showSummaryPlot == 1
    
    x = 1:1.2*vMax;
    xNC = 5*dx:5*dx:vMax;
    
    figure(2), clf,
    subplot(2,2,1), hold on,
        for t=1:T
            signal{t} = sc.minSub.frame(t).selected;
        end
        distributionPlot(signal,1,0);
        plot(sc.AFsub.mSig,'b','linewidth',2);
        xlabel('time frame','fontsize',12);
        ylabel('Protein distribution (a.u.)','fontsize',12);
        set(gca,'linewidth',1.5,'fontsize',12);
        set(gca,'xTick',5:5:T);
        axis([0.5 T+0.5 0 vMax]);
        title('minSub signal','fontsize',12);
        
    subplot(2,2,2), hold on,
        rndDist = zeros(N,T);
        for t=1:T
            rndDist(:,t) = gamrnd(sc.AFsub.kFFT(t),sc.AFsub.tFFT(t),1,N);
        end
        distributionPlot(rndDist,1,0);
        plot(sc.AFsub.kFFT.*sc.AFsub.tFFT,'b','linewidth',2);
        xlabel('time frame','fontsize',12);
        ylabel('Protein distribution (a.u.)','fontsize',12);
        set(gca,'linewidth',1.5,'fontsize',12);
        set(gca,'xTick',5:5:T);
        axis([0.5 T+0.5 0 vMax]);
        title('FFT method','fontsize',12);
        
    subplot(2,2,3), hold on,
        rndDist = zeros(N,T);
        for t=1:T
            rndDist(:,t) = gamrnd(sc.AFsub.kFit(t),sc.AFsub.tFit(t),1,N);
        end
        distributionPlot(rndDist,1,0);
        plot(sc.AFsub.kFit.*sc.AFsub.tFit,'b','linewidth',2);
        xlabel('time frame','fontsize',12);
        ylabel('Protein distribution (a.u.)','fontsize',12);
        set(gca,'linewidth',1.5,'fontsize',12);
        set(gca,'xTick',5:5:T);
        axis([0.5 T+0.5 0 vMax]);
        title('Fit method','fontsize',12);
    
    if nsamples ~= 0
        subplot(2,2,4), hold on,
            rndDist = zeros(N,T);
            for t=1:T
                rndDist(:,t) = gamrnd(sc.AFsub.kMCMC(t),sc.AFsub.tMCMC(t),1,N);
            end
            distributionPlot(rndDist,1,0);
            plot(sc.AFsub.mmMCMC,'b','linewidth',2);
            patch([1:T T+1-(1:T)],[sc.AFsub.mmMCMC+sc.AFsub.msMCMC sc.AFsub.mmMCMC(T+1-(1:T))-sc.AFsub.msMCMC(T+1-(1:T))],'b','edgecolor','none');
            alpha(0.5);
            %plot(sc.AFsub.kMCMC.*sc.AFsub.tMCMC,'r','linewidth',2);
            xlabel('time frame','fontsize',12);
            ylabel('Protein distribution (a.u.)','fontsize',12);
            set(gca,'linewidth',1.5,'fontsize',12);
            set(gca,'xTick',5:5:T);
            axis([0.5 T+0.5 0 vMax]);
            title('MCMC method','fontsize',12);
    end
        
    print(2,'-dpng',fullfile(summaryPlotDir,sprintf('AFsubSummary_pos%d_%c_.png',p,side)));

end


