% nd_analysisPipeline.m


%% Inputs

% Experiment info
%info.mainDataDirectory = 'S:\denervaud\YGFP_data';
%info.mainDataDirectory = 'R:\denervaud\RP_data';
%info.mainDataDirectory = '//lbnc-4/denervaud/RP_data';
%info.expName = 'RP_20120611';
%info.position = 1;
%info.scDir = fullfile('singleCellData','SCanalysis_20120611');

info.mainDataDirectory = 'replaceMain';
info.expName = 'replaceExp';
info.position = replacePos;
info.scDir = fullfile('singleCellData','replaceSC');

% Directories
info.rawImageDir = 'rawImage';
info.rotatedDir = 'rotatedImage';
info.epiMovieDir = 'rotated_Movies_epi';
info.epiNiceMovieDir = 'rotated_Movies_epiNice';
info.diaMovieDir = 'rotated_Movies_dia';
info.logDir = fullfile(info.scDir,'logFiles');
info.infoDir = fullfile(info.scDir,'infoFiles');
info.trackerMacroFile = fullfile(pwd,'cellTrackerMacro.txt');
%info.jarDir = 'C:\Program Files\ImageJ\ij.jar';
info.jarDir = '/lbnc-soft/usr/ImageJ_64/ij.jar';
%info.ijDir = 'C:\Program Files\ImageJ\plugins';
info.ijDir = '/lbnc-soft/usr/ImageJ_64/plugins';
%info.javaOption = '-Xmx1600m';
info.javaOption = '-Xmx2048m';
%info.javaDisplay = '';
info.javaDisplay = 'DISPLAY=:3';
info.movieMacroFile = fullfile(pwd,'makeSingleMovieContrast.txt');
info.expDirectory = fullfile(info.mainDataDirectory,info.expName);

info.side = {'L' 'R'};
info.Nstart = 1;
info.Nend = 18;


%% Options

info.saveLog = 1;

% chamberSeparator
info.chamberSeparator.run = 1;
info.chamberSeparator.showFigure = 0;
info.chamberSeparator.templateFile = 'postChamber_60x.tif';
%info.chamberSeparator.templateFile = 'postsTemplate_optimized6.tif';
%info.chamberSeparator.templateFile = 'HWTemplate_2.tif';
info.chamberSeparator.chamberOffset.xL = -25; % 90x -> -45, 60x -> -25
info.chamberSeparator.chamberOffset.yL = 395;
info.chamberSeparator.chamberOffset.xR = 25; % 90x -> 45, 60x -> 25
info.chamberSeparator.chamberOffset.yR = 395;
info.chamberSeparator.fluoCorrFile = 'CFP_correction_20120224.tif';
% info.chamberSeparator.fluoCorrFile = '';


% ImageJ movieMaker
info.movieMaker.run = 1;

% Matlab epi movie maker
info.epiMovieMaker.run = 0;
info.compressor = 'k'; % none for UNIX machine
info.movieQuality = 90;
info.epiColor = 2; % 0 -> gray, 1 -> red, 2 -> green, 3 -> blue

% cellTracker
info.cellTracker.run = 1;

% cellSorting
info.cellSorting.run = 1;
info.cellSorting.bndThresh = 20;
info.cellSorting.sizeSafe = [132 744]; % Safety gate (60x [132 744] - 90x [300 744])
info.cellSorting.sizePercentile = [2 98]; % percentile for gating
info.cellSorting.outlierFactor = 100;
info.cellSorting.outliersMethod = 0;  % 0 -> mean/std method, 1 -> percentile/IQR method, 2 -> Both true
info.cellSorting.showSelection = 0; % Set to 0 with cluster (requires display)
info.cellSorting.saveCoord = 1;
info.cellSorting.printDPI = 150;
info.cellSorting.showSummaryPlot = 1;
info.cellSorting.showIndividualPlot = 1; 
info.cellSorting.summaryOption = 3; % 1 -> only selected points, 2 -> all and selected points
info.cellSorting.individualOption = 4; % 3 -> outliers and selected points, 4 -> all, outliers and selected points

% AF sub
info.AFsub.run = 0;
info.AFsub.AFtype = 3; % AF fitted with: 1-> normal, 2-> gamma, 3-> log normal
info.AFsub.showSummaryPlot = 0; % Segmentation fault ...
info.AFsub.showFramePlot = 1;
info.AFsub.Nplot = 1000;
info.AFsub.Ts = 1;
info.AFsub.Tstart = 0.1;
info.AFsub.nsamples = 2000;
info.AFsub.nstart = 100;
info.AFsub.sigma = [0.05 0.05];
    
% Extraction of localization features
info.locFeat.run = 0;


%% Run

infoSave = info;
for p = info.position
    info.position = p;
    if info.saveLog == 1
        mkdir(fullfile(info.expDirectory,info.logDir));
        fid = fopen(fullfile(info.expDirectory,info.logDir,sprintf('%s_pos%d.log',info.expName,p)),'w');
    else
        fid = 1;
    end
    fprintf(fid,'Analysis pipeline - experiment %s, position %d\n\n',info.expName,p);
    fprintf(fid,'Parameters:\n');
    nd_writeStruct(fid,1,info);
    fprintf(fid,'\nRunning analysis:\n');

    % 1. ChamberSeparator
    if info.chamberSeparator.run == 1      
        fprintf(fid,'\tChamberSeparator: experiment %s, position %d ...\n',info.expName,p);
        try
            chamberSeparatorCluster(info);
            info.MEseparator = [];
            fprintf(fid,'\t\tDone.\n');
        catch MEseparator
            info.MEseparator = MEseparator;
            fprintf(fid,'\t\tError: %s\n',MEseparator.message);
        end

    else
        fprintf(fid,'\tNo chamberSeparator.\n');
    end

    % 2. ImageJ movieMaker
    if info.movieMaker.run == 1
        fprintf(fid,'\tImageJ movieMaker: experiment %s, position %d ...\n',info.expName,p);
        try
            MEmovieMoveFile = makeSingleMovieContrast(info);
            if ~isempty(MEmovieMoveFile)
                fprintf(fid,'\t\tWarning: %s -> force copying\n',MEmovieMoveFile.message);
            end
            info.MEmovie = [];
            info.MEmovieMoveFile = [];
            fprintf(fid,'\t\tDone.\n');
        catch MEmovie
            info.MEmovieMoveFile = [];
            info.MEmovie = MEmovie;
            fprintf(fid,'\t\tError: %s\n',MEmovie.message);
        end
    else
        fprintf(fid,'\tNo ImageJ movieMaker.\n');
    end
    
    % 3. Matlab epi movieMaker
    if info.epiMovieMaker.run == 0
        fprintf(fid,'\tMatlab epi movieMaker: experiment %s, position %d ...\n',info.expName,p);
        try
            makeSingleMovie_matlab(info);    
            info.MEmatlabMovie = [];
            fprintf(fid,'\t\tDone.\n');
        catch MEmatlabMovie
            info.MEmatlabMovie = MEmatlabMovie;
            fprintf(fid,'\t\tError: %s\n',MEmatlabMovie.message);
        end
    else
        fprintf(fid,'\tNo Matlab epi movieMaker.\n');
    end

    % 4. cellTracker
    if info.cellTracker.run == 1
        for k=1:numel(info.side)
            fprintf(fid,'\tcellTracker: experiment %s, position %d, %s ...\n',info.expName,p,info.side{k});
            try
                MEtrackerMoveFile = nd_runCellTracker(info,info.side{k});
                if ~isempty(MEtrackerMoveFile)
                    fprintf(fid,'\t\tWarning: %s -> force copying\n',MEtrackerMoveFile.message);
                end
                info.MEtracker = [];
                info.MEtrackerMoveFile = [];
                fprintf(fid,'\t\tDone.\n');
            catch MEtracker
                info.MEtrackerMoveFile = [];
                info.MEtracker = MEtracker;
                fprintf(fid,'\t\tError: %s\n',MEtracker.message);
            end
        end
    else
        fprintf(fid,'\tNo cellTracker.\n');
    end

    % 5. CellSorting
    if info.cellSorting.run == 1
        for k=1:numel(info.side)
            fprintf(fid,'\tcellSorting: experiment %s, position %d, %s ...\n',info.expName,p,info.side{k});
            try
                nd_scSort(info,info.side{k});
                info.MEsorting = [];
                fprintf(fid,'\t\tDone.\n');
            catch MEsorting
                info.MEsorting = MEsorting;
                fprintf(fid,'\t\tError: %s\n',MEsorting.message);
            end
        end
    else
        fprintf(fid,'\tNo cellSorting.\n');
    end

    % 6. AF sub
    if info.AFsub.run == 1
        for k=1:numel(info.side)
            fprintf(fid,'\tAF sub: experiment %s, position %d, %s ...\n',info.expName,p,info.side{k});
            try
                nd_AFsub_mcmc_fct(info,info.side{k},fid);
                info.ME_AFsub = [];
                fprintf(fid,'\t\tDone.\n');
            catch ME_AFsub
                info.ME_AFsub = ME_AFsub;
                fprintf(fid,'\t\tError: %s\n',ME_AFsub.message);
            end
        end
    else
        fprintf(fid,'\tNo AF sub.\n');
    end

    % 7. extraction of localization features
    if info.locFeat.run == 1
        for k=1:numel(info.side)
            fprintf(fid,'\tExtraction of localiztion features: experiment %s, position %d, %s ...\n',info.expName,p,info.side{k});
            try
                nd_smallSet_fct(info,info.side{k});
                info.ME_locFeat = [];
                fprintf(fid,'\t\tDone.\n');
            catch ME_locFeat
                info.ME_locFeat = ME_locFeat;
                fprintf(fid,'\t\tError: %s\n',ME_locFeat.message);
            end
        end
    else
        fprintf(fid,'\tNo extraction of localiztion features.\n');
    end

    mkdir(fullfile(info.expDirectory,info.infoDir));
    save(fullfile(info.expDirectory,info.infoDir,sprintf('info_%s_pos%d.mat',info.expName,p)));

    fprintf(fid,'\nAnalysis done.\nData saved.\n');
    if info.saveLog == 1, fclose(fid); end
    
    info = infoSave;
end

