function [feat_names, feat_vals] = nd_features_smallSet(procimage, imagemask)

procimage = double(procimage);

if (max(max(procimage))==0)
    feat_names = [];
    feat_vals = [];
    warning('Image has no non-zero pixels in it');
    return;
end
feat_names = [];
feat_vals = [];


% 1. ND histo features
% hvalues = nd_histoFeat(procimage,imagemask,32);
% hnames = {'top5ratio' 'top10ratio' 'top20ratio' 'histo1ratio' 'histo2ratio' 'histo3ratio' 'histoHLratio' ...
%     'bin1ratio' 'bin2ratio' 'bin3ratio' 'binHLratio'};
hvalues = nd_histoFeat2(procimage,imagemask,16);
hnames = {'top5vs20' 'top5vs50' 'top20vs50' 'top5vsMed' 'top20vsMed' 'top50vsMed' 'histo1ratio' 'histo2ratio' 'histo3ratio' 'histoHLratio' ...
    'bin1vs2' 'bin1vs3' 'bin2vs3' 'bin1vsMed' 'bin2vsMed' 'bin3vsMed' 'binHLratio'};
feat_names = [feat_names hnames];
feat_vals = [feat_vals hvalues];


% 2. ND geometry features
gvalues = nd_geometryFeat(procimage,imagemask);
gnames = {'central_signal' 'middle signal' 'boundary_signal'};   
feat_names = [feat_names gnames];
feat_vals = [feat_vals gvalues];


% 3. Morphological set
maskedImage = procimage/255;
maskedImage(imagemask == 0) = 0;
[hullnames, hullvalues] = nd_hullfeatures(maskedImage,imagemask);
[edgenames, edgevalues] = nd_imgedgefeatures(maskedImage);
feat_names = [feat_names hullnames edgenames];
feat_vals = [feat_vals hullvalues edgevalues];


% 4. ND granulometries
radii = [1 2 4 7 12];
[grnames, grvalues] = nd_granulometry2(procimage,imagemask,radii);   
feat_names = [feat_names grnames];
feat_vals = [feat_vals grvalues];


% 5. threshold adjacency statistics
maskedImage = procimage/255;
maskedImage(imagemask == 0) = 0;
[tvalues, tasnames] = jb_tas(maskedImage);
feat_names = [feat_names tasnames];
feat_vals = [feat_vals tvalues];


% 6. threshold adjacency statistics
% Invert image
invertedImage = 1-procimage/255;
invertedImage(imagemask == 0) = 0;
[tvalues, tasnames] = jb_tas_inverted(invertedImage);
feat_names = [feat_names tasnames];
feat_vals = [feat_vals tvalues];

end


   

