function feature = nd_histoFeat2(I,mask,Nbin)

cellArea = sum(sum(mask));
cellIdx = find(mask == 1);

% Top pixels
Inorm = ceil(mat2gray(I)*256);
Inorm(Inorm == 0) = 1;
medianFluo = median(Inorm(cellIdx));

% topPixels
pixSorted = sort(Inorm(cellIdx),'descend');
if cellArea > 50
    top5 = mean(pixSorted(1:5));
    top20 = mean(pixSorted(1:20));
    top50 = mean(pixSorted(1:50));
    top5vs20 = top5/top20;
    top5vs50 = top5/top50;
    top20vs50 = top20/top50;
    top5vsMed = top5/medianFluo;
    top20vsMed = top20/medianFluo;
    top50vsMed = top50/medianFluo;
else
    top5vs20 = NaN;
    top5vs50 = NaN;
    top20vs50 = NaN;
    top5vsMed = NaN;
    top20vsMed = NaN;
    top50vsMed = NaN;
end

% histogram info
histo = hist(Inorm(cellIdx),Nbin)/cellArea;
histo1ratio = histo(Nbin)/mean(histo(1:Nbin/2));
histo2ratio = histo(Nbin-1)/mean(histo(1:Nbin/2));
histo3ratio = histo(Nbin-2)/mean(histo(1:Nbin/2));
histoHLratio = mean(histo(Nbin/2+1:Nbin))/mean(histo(1:Nbin/2));

% bin limits
binning = prctile(Inorm(cellIdx),(1:Nbin-1)/Nbin*100);
bin1vs2 = binning(Nbin-1)/binning(Nbin-2);
bin1vs3 = binning(Nbin-1)/binning(Nbin-3);
bin2vs3 = binning(Nbin-2)/binning(Nbin-3);
bin1vsMed = binning(Nbin-1)/medianFluo;
bin2vsMed = binning(Nbin-2)/medianFluo;
bin3vsMed = binning(Nbin-3)/medianFluo;
binHLratio = binning(round(Nbin/4))/binning(round(3*Nbin/4));

feature = [top5vs20 top5vs50 top20vs50 top5vsMed top20vsMed top50vsMed histo1ratio histo2ratio histo3ratio histoHLratio ...
    bin1vs2 bin1vs3 bin2vs3 bin1vsMed bin2vsMed bin3vsMed binHLratio];

end