function nd_scSort(info,side)

% Cell sorting: mixed approach
% -> fixed threshold on boundary
% -> size gating
% -> quality criteria based on segmentation type
%    Ovuscule -> circularity (8),ovuscule energy (14), ext/int dia (3), std/mean dia (1)
%    Snake    -> circularity (8),snake energy (13), ext/int dia (3), std/mean dia (1)
%    Region -> circularity (8), convex/area (6), ext/int dia (3), std/mean dia (1)

expDirectory = info.expDirectory;
expName = info.expName;
rotatedDir = info.rotatedDir;
scAnalysisDir = info.scDir;
p = info.position;

% Parameters
bndThresh = info.cellSorting.bndThresh;
sizeSafe = info.cellSorting.sizeSafe;
sizePercentile = info.cellSorting.sizePercentile;
outlierFactor = info.cellSorting.outlierFactor;
outliersMethod = info.cellSorting.outliersMethod;

% Options
showSelection = info.cellSorting.showSelection;
saveCoord = info.cellSorting.saveCoord;
printDPI = info.cellSorting.printDPI;
showSummaryPlot = info.cellSorting.showSummaryPlot;
showIndividualPlot = info.cellSorting.showIndividualPlot;
summaryOption = info.cellSorting.summaryOption; 
individualOption = info.cellSorting.individualOption;

% load classifers
load('svmStructOvusc');
load('svmStructSnake');
load('svmStructRegion');

% Gene name
if side == 'L';
    sideNum = 2;
else
    sideNum = 1;
end
X = load(fullfile(expDirectory,'expData.mat'));
expData = X.expData;
gn = expData{p,sideNum}.geneName;
if strcmp(gn,'none') == 1 || isempty(gn) , gn = expData{p,sideNum}.yORF; end

% Directories
scMainDir = fullfile(expDirectory,scAnalysisDir);
scDir = fullfile(scMainDir,sprintf('pos%d_%s',p,side));
rawImageDir = fullfile(expDirectory,rotatedDir,sprintf('pos%d_%s',p,side));
dirOut = dir(fullfile(scDir,'*_singlecelloutline.txt'));
filenameCoord = {dirOut.name}';
dirOutput = dir(fullfile(scDir,'*_singlecell.txt'));
filename = {dirOutput.name}';   

% Import data
scData = importdata(fullfile(scDir,filename{1}));      
[nbRow, nbCol] = size(scData);
T = max(scData(:,1))+1;
dirDia = dir(fullfile(rawImageDir,'dia','*.tif'));
diaFiles = {dirDia.name}';
Dia = imread(fullfile(rawImageDir,'dia',diaFiles{1}));
[w h]=size(Dia);
clear Dia

%infoNames = {'distance' 'area' 'circularity' 'cellNoise' 'extintRatio ' 'segRegRatio' 'segType' 'segQuality'};
%fluoNames = {'area' 'wsMean' 'scMean 'sc3top' 'sc5top' 'scMedian' 'scMin' 'scBGmin' 'sc5min' 'scBG5min'};

for t=1:T
    frameIdx = find(scData(:,1)==(t-1));
    frameData = scData(frameIdx,3:end);
    distance = min([frameData(:,1) h-frameData(:,1) frameData(:,2) w-frameData(:,2)],[],2); 
    area = frameData(:,6);
    circularity = frameData(:,25);
    cellNoise = frameData(:,26);
    extIntRatio = frameData(:,28);
    segRegRatio = frameData(:,6)./frameData(:,3);
    segType = frameData(:,23);
    segQuality = frameData(:,24);
    scInfo{t} = [distance area circularity cellNoise extIntRatio segRegRatio segType segQuality];
    scFluo{t} = frameData(:,[6 5 8 10 12 14 16 18 20 22]); % Channel 2: 'area' 'wsMean' 'scMean 'sc3top' 'sc5top' 'scMedian' 'scMin' 'scBGmin' 'sc5min' 'scBG5min'
end
clear scData frameData
save(fullfile(scDir,'scInfo.mat'),'scInfo'); 
save(fullfile(scDir,'scFluo.mat'),'scFluo'); 

% Get frame time
for t=1:T
    
    timeString = regexp(diaFiles{t},'_t(\d+)_(\d+).tif','tokens');
    date(t) = str2double(timeString{1}{1});
    writeTime = timeString{1}{2};
    time(t,:) = sscanf(writeTime,'%2f %2f %2f');
    
%     if sideNum == 2
%         date(t) = sscanf(diaFiles{t},'left_dia_pos%*d_t%8d');
%         time(t,:) = sscanf(diaFiles{t},'left_dia_pos%*d_t%*8d_%2d %2d %2d');
%     else
%         date(t) = sscanf(diaFiles{t},'right_dia_pos%*d_t%8d');
%         time(t,:) = sscanf(diaFiles{t},'right_dia_pos%*d_t%*8d_%2d %2d %2d');
%     end
end
timeC = time(:,1)+time(:,2)/60+time(:,3)/3600;
t0 = timeC(1);

for t=1:T
    diffDate = datenum(num2str(date(t)),'yyyymmdd')-datenum(num2str(date(1)),'yyyymmdd');
    if diffDate == 0
        timing(t) = timeC(t)-t0;
    elseif diffDate > 0
        timing(t) = 24-t0+timeC(t)+(diffDate-1)*24;
    end
    frame(t).date = date(t);
    frame(t).time = time(t);
    frame(t).timing = timing(t);
end

% Get switch data
X = load(fullfile(expDirectory,'switchData.mat'));
switchData = X.switchData;
Nswitch = size(switchData.date,1);
switchTimeC = switchData.time(:,1)+switchData.time(:,2)/60+switchData.time(:,3)/3600;
for n=1:Nswitch
    diffSwitchDate = datenum(num2str(switchData.date(n)),'yyyymmdd')-datenum(num2str(date(1)),'yyyymmdd');
    if diffSwitchDate == 0
        switchTiming(n) = switchTimeC(n)-t0;
    elseif diffSwitchDate > 0
        switchTiming(n) = 24-t0+switchTimeC(n)+(diffSwitchDate-1)*24;
    end
    condition{n} = switchData.condition{n};
end

% Import coordinates
if showSelection == 1 || saveCoord == 1
    fid = fopen(fullfile(scDir,filenameCoord{1}));
    tline = fgetl(fid);
    trow = str2num(tline);
    frame = trow(1)+1;
    for t=1:T
        clear CoordX CoordY;
        count = 0;
        while frame == t
            count = count+1;
            coord = trow(3:end);
            Nc = numel(coord)/2;
            CoordX(count,:) = coord(1:Nc);
            CoordY(count,:) = coord(Nc+1:end);

            tline = fgetl(fid);
            if ~ischar(tline),   break,   end
            trow = str2num(tline);
            frame = trow(1)+1;
        end
        cX{t} = CoordX;
        cY{t} = CoordY;    
    end
    fclose(fid);  
    save(fullfile(scDir,'cX.mat'),'cX');
    save(fullfile(scDir,'cY.mat'),'cY');
end
clear tline

% Cell sorting (mixed approach) 
for t=1:T
    info = scInfo{t};
    nC = size(info,1);
    mixedLabel = zeros(nC,3);  % 1 -> discard

    % a. threshold on boundary
    bndIdx = find(info(:,1) < bndThresh);
    mixedLabel(bndIdx,1) = 1;

    % b. Size gating
    areaIdx = find(mixedLabel(:,1) == 0);
    areaPercentile = prctile(info(areaIdx,2),sizePercentile);
    sizeGate(1) = max(sizeSafe(1),areaPercentile(1));
    sizeGate(2) = min(sizeSafe(2),areaPercentile(2));
    sizeIdx = find(((info(:,2)>sizeGate(2))+(info(:,2)<sizeGate(1))) > 0);
    mixedLabel(sizeIdx,2) = 1;

    % c. Quality classifier
    % Ovusc Type
    idxOvusc = find(info(:,7) == 0);
    dataOvusc = info(idxOvusc,[3 5 6 8]);
    predOvusc = svmclassify(svmStructOvusc,dataOvusc);
    mixedLabel(idxOvusc,3) = predOvusc;

    % Snake Type
    idxSnake = find(info(:,7) == 1);
    dataSnake = info(idxSnake,[3 5 6 8]);
    predSnake = svmclassify(svmStructSnake,dataSnake);
    mixedLabel(idxSnake,3) = predSnake;

    % Region Type
    idxRegion = find(info(:,7) == 2);
    dataRegion = info(idxRegion,[3 5 6 8]);
    predRegion = svmclassify(svmStructRegion,dataRegion);
    mixedLabel(idxRegion,3) = predRegion;

    label{t} = sum(mixedLabel,2) > 0;
    nbCell.all(t) = nC;
    nbCell.discard(t) = sum(label{t});
    nbCell.good(t) = nbCell.all(t)-nbCell.discard(t);
    mixLabel{t} = mixedLabel;
end
clear info
save(fullfile(scDir,'cellLabel.mat'),'label');
save(fullfile(scDir,'nbCell.mat'),'nbCell');

% Show cell selection
if showSelection == 1
    sortResultsDir = fullfile(scDir,'sortingResults');
    mkdir(sortResultsDir);
    for t=1:T
        clear CoordX CoordY;
        Dia = imread(fullfile(rawImageDir,'dia',diaFiles{t}));
        nbCells = nbCell.all(t);
        coordX = cX{t};
        coordY = cY{t};
        mixedLabel = mixLabel{t};
        figure(10), clf;
        subplot(1,3,1),
            imshow(imadjust(Dia));
            for j = 1:nbCells
                x=coordX(j,:);
                xcorr=x(isnan(x)==0);
                y=coordY(j,:);
                ycorr=y(isnan(y)==0);
                if mixedLabel(j,1)  == 1
                    line(xcorr, ycorr,'Color','r');
                else
                    line(xcorr, ycorr,'Color','g');
                end
            end
            title('boundary');
        subplot(1,3,2),
            imshow(imadjust(Dia));
            for j = 1:nbCells
                if mixedLabel(j,1) == 0
                    x=coordX(j,:);
                    xcorr=x(isnan(x)==0);
                    y=coordY(j,:);
                    ycorr=y(isnan(y)==0);
                    if mixedLabel(j,2)  == 1
                        line(xcorr, ycorr,'Color','r');
                    else
                        line(xcorr, ycorr,'Color','g');
                    end
                end
            end
            title('size gating');
        subplot(1,3,3), 
            imshow(imadjust(Dia));
            for j = 1:nbCells
                if sum(mixedLabel(j,[1 2])) == 0
                    x=coordX(j,:);
                    xcorr=x(isnan(x)==0);
                    y=coordY(j,:);
                    ycorr=y(isnan(y)==0);
                    if mixedLabel(j,3)  == 1
                        line(xcorr, ycorr,'Color','r');
                    else 
                        line(xcorr, ycorr,'Color','g');
                    end
                end
            end
            title('quality classifier');
        print(10,'-dpng',sprintf('-r%d',printDPI),fullfile(sortResultsDir,sprintf('mixedSorting_frame%d.png',t)));
    end
end


% Remove outliers
for t=1:T
    all = scFluo{t}; %Channel 2: 'area' 'wsMean' 'scMean 'sc3top' 'sc5top' 'scMedian' 'scMin' 'scBGmin' 'sc5min' 'scBG5min'
    sortedIdx = find(label{t}==0);
    sorted = all(sortedIdx,3)-all(sortedIdx,7);  % bg subtraction with scMin
    if outliersMethod == 1
        framePercentile = prctile(sorted,[25 75]);
        IQR = framePercentile(:,2)-framePercentile(:,1);
        outliers = (sorted > (framePercentile(:,2)+outlierFactor*IQR)) + (sorted < (framePercentile(:,1)-outlierFactor*IQR)); 
    elseif outliersMethod == 0
        frameMean = mean(sorted);
        frameStd = std(sorted);
        outliers = (sorted > (frameMean+outlierFactor*frameStd)) + (sorted < (frameMean-outlierFactor*frameStd)); 
    else
        frameMean = mean(sorted);
        frameStd = std(sorted);
        framePercentile = prctile(sorted,[25 75]);
        IQR = framePercentile(:,2)-framePercentile(:,1);
        outliersPRCT = (sorted > (framePercentile(:,2)+outlierFactor*IQR)) + (sorted < (framePercentile(:,1)-outlierFactor*IQR)); 
        outliersSTD = (sorted > (frameMean+outlierFactor*frameStd)) + (sorted < (frameMean-outlierFactor*frameStd)); 
        outliers = outliersPRCT .* outliersSTD;
    end
    outLabel = zeros(size(all,1),1);
    outLabel(sortedIdx) = outliers;
    outliersLabel{t} = outLabel;
    outFreeInfo{t} = sorted(outliers==0,:);
    nbCell.outliers(t) = sum(outliers);
end
save(fullfile(scDir,'nbCell.mat'),'nbCell');
save(fullfile(scDir,'outFreeInfo.mat'),'outFreeInfo');
save(fullfile(scDir,'outliersLabel.mat'),'outliersLabel');

% Save selected coordinates
if saveCoord == 1
    coordSelDir = fullfile(scDir,'CoordSelectedCells');
    mkdir(coordSelDir);
    for t=1:T
        qualiLabel = label{t};
        outLabel = outliersLabel{t};
        selLabel = qualiLabel+outLabel;
        coordX = cX{t};
        coordY = cY{t};
        CoordSelX = coordX(selLabel == 0,:);
        CoordSelY = coordY(selLabel == 0,:);
        dlmwrite(fullfile(coordSelDir,sprintf('CoordSelx_frame%d.txt',t)), CoordSelX);
        dlmwrite(fullfile(coordSelDir,sprintf('CoordSely_frame%d.txt',t)), CoordSelY);
    end
end
clear CoordX CoordY cX cY
% Single cell data summary
dataDir = fullfile(scMainDir,'scData');
mkdir(dataDir);

for t=1:T

    qualiLabel = label{t};
    outLabel = outliersLabel{t};
    selLabel = qualiLabel+outLabel;

    all = scFluo{t}; % Channel 2: 'area' 'wsMean' 'scMean 'sc3top' 'sc5top' 'scMedian' 'scMin' 'scBGmin' 'sc5min' 'scBG5min'
    discarded = all(qualiLabel == 1,:);
    out = all(outLabel==1,:);
    selected = all(selLabel==0,:);
    
    % area
    sc.area.frame(t).selected = selected(:,1);
    sc.area.frame(t).all = all(:,1);
    sc.area.frame(t).out = out(:,1);
    sc.area.mean(t) = mean(selected(:,1));
    sc.area.std(t) = std(selected(:,1));
    
    % sc watershed
    sc.water.frame(t).selected = selected(:,2);
    sc.water.frame(t).all = all(:,2);
    sc.water.frame(t).out = out(:,2);
    sc.water.mean(t) = mean(selected(:,2));
    sc.water.std(t) = std(selected(:,2));
    
    % raw
    sc.raw.frame(t).selected = selected(:,3);
    sc.raw.frame(t).all = all(:,3);
    sc.raw.frame(t).out = out(:,3);
    sc.raw.mean(t) = mean(selected(:,3));
    sc.raw.std(t) = std(selected(:,3));
      
    % sc min
    sc.min.frame(t).selected = selected(:,7);
    sc.min.frame(t).all = all(:,7);
    sc.min.frame(t).out = out(:,7);
    sc.min.mean(t) = mean(selected(:,7));
    sc.min.std(t) = std(selected(:,7));
    
    % sc BG min
    sc.BGmin.frame(t).selected = selected(:,8);
    sc.BGmin.frame(t).all = all(:,8);
    sc.BGmin.frame(t).out = out(:,8);
    sc.BGmin.mean(t) = mean(selected(:,8));
    sc.BGmin.std(t) = std(selected(:,8));
    
    % sc 5 min
    sc.min5.frame(t).selected = selected(:,9);
    sc.min5.frame(t).all = all(:,9);
    sc.min5.frame(t).out = out(:,9);
    sc.min5.mean(t) = mean(selected(:,9));
    sc.min5.std(t) = std(selected(:,9));
    
    % sc BG 5 min
    sc.BGmin5.frame(t).selected = selected(:,10);
    sc.BGmin5.frame(t).all = all(:,10);
    sc.BGmin5.frame(t).out = out(:,10);
    sc.BGmin5.mean(t) = mean(selected(:,10));
    sc.BGmin5.std(t) = std(selected(:,10));
    
    % sc fluo min sub
    sc.minSub.frame(t).selected = selected(:,3)-selected(:,7);
    sc.minSub.frame(t).all = all(:,3)-all(:,7);
    sc.minSub.frame(t).out = out(:,3)-out(:,7);
    sc.minSub.mean(t) = mean(selected(:,3)-selected(:,7));
    sc.minSub.std(t) = std(selected(:,3)-selected(:,7));
    
    % sc fluo BG min sub
    sc.BGminSub.frame(t).selected = selected(:,3)-selected(:,8);
    sc.BGminSub.frame(t).all = all(:,3)-all(:,8);
    sc.BGminSub.frame(t).out = out(:,3)-out(:,8);
    sc.BGminSub.mean(t) = mean(selected(:,3)-selected(:,8));
    sc.BGminSub.std(t) = std(selected(:,3)-selected(:,8));
    
    % sc fluo min 5 sub
    sc.min5Sub.frame(t).selected = selected(:,3)-selected(:,9);
    sc.min5Sub.frame(t).all = all(:,3)-all(:,9);
    sc.min5Sub.frame(t).out = out(:,3)-out(:,9);
    sc.min5Sub.mean(t) = mean(selected(:,3)-selected(:,9));
    sc.min5Sub.std(t) = std(selected(:,3)-selected(:,9));
    
    % sc fluo BG min 5 sub
    sc.BGmin5Sub.frame(t).selected = selected(:,3)-selected(:,10);
    sc.BGmin5Sub.frame(t).all = all(:,3)-all(:,10);
    sc.BGmin5Sub.frame(t).out = out(:,3)-out(:,10);
    sc.BGmin5Sub.mean(t) = mean(selected(:,3)-selected(:,10));
    sc.BGmin5Sub.std(t) = std(selected(:,3)-selected(:,10));
    
    % 3 top pixels
    sc.top3.frame(t).selected = selected(:,4)-selected(:,9);
    sc.top3.frame(t).all = all(:,4)-all(:,9);
    sc.top3.frame(t).out = out(:,4)-out(:,9);
    sc.top3.mean(t) = mean(selected(:,4)-selected(:,9));
    sc.top3.std(t) = std(selected(:,4)-selected(:,9));
    
    % 5 top pixels
    sc.top5.frame(t).selected = selected(:,5)-selected(:,9);
    sc.top5.frame(t).all = all(:,5)-all(:,9);
    sc.top5.frame(t).out = out(:,5)-out(:,9);
    sc.top5.mean(t) = mean(selected(:,5)-selected(:,9));
    sc.top5.std(t) = std(selected(:,5)-selected(:,9));
    
    % top 3 pixels / median
    sc.top3Med.frame(t).selected = (selected(:,4)-selected(:,9))./(selected(:,6)-selected(:,9));
    sc.top3Med.frame(t).all = (all(:,4)-all(:,9))./(all(:,6)-all(:,9));
    sc.top3Med.frame(t).out = (out(:,4)-out(:,9))./(out(:,6)-out(:,9));
    sc.top3Med.mean(t) = mean((selected(:,4)-selected(:,9))./(selected(:,6)-selected(:,9)));
    sc.top3Med.std(t) = std((selected(:,4)-selected(:,9))./(selected(:,6)-selected(:,9)));
      
    % top 5 pixels / median
    sc.top5Med.frame(t).selected = (selected(:,5)-selected(:,9))./(selected(:,6)-selected(:,9));
    sc.top5Med.frame(t).all = (all(:,5)-all(:,9))./(all(:,6)-all(:,9));
    sc.top5Med.frame(t).out = (out(:,5)-out(:,9))./(out(:,6)-out(:,9));
    sc.top5Med.mean(t) = mean((selected(:,5)-selected(:,9))./(selected(:,6)-selected(:,9)));
    sc.top5Med.std(t) = std((selected(:,5)-selected(:,9))./(selected(:,6)-selected(:,9)));

end

% area
sc.area.condition = condition;
sc.area.switchTiming = switchTiming;
sc.area.timing = timing;
sc.area.xLabel = 'time (hours)';
sc.area.yLabel = 'single cell area (pixels)';
sc.area.title = sprintf('Single cell area - %s',gn);

% Watershed
sc.water.condition = condition;
sc.water.switchTiming = switchTiming;
sc.water.timing = timing;
sc.water.xLabel = 'time (hours)';
sc.water.yLabel = 'single cell fluorescence (a.u.)';
sc.water.title = sprintf('Single cell watershed - %s',gn);

% Raw
sc.raw.condition = condition;
sc.raw.switchTiming = switchTiming;
sc.raw.timing = timing;
sc.raw.xLabel = 'time (hours)';
sc.raw.yLabel = 'single cell fluorescence (a.u.)';
sc.raw.title = sprintf('Single cell raw - %s',gn);

% min
sc.min.condition = condition;
sc.min.switchTiming = switchTiming;
sc.min.timing = timing;
sc.min.xLabel = 'time (hours)';
sc.min.yLabel = 'min fluorescence (a.u.)';
sc.min.title = sprintf('Single cell Min - %s',gn);

% BG min
sc.BGmin.condition = condition;
sc.BGmin.switchTiming = switchTiming;
sc.BGmin.timing = timing;
sc.BGmin.xLabel = 'time (hours)';
sc.BGmin.yLabel = 'min fluorescence (a.u.)';
sc.BGmin.title = sprintf('Single cell BGmin - %s',gn);

% min 5
sc.min5.condition = condition;
sc.min5.switchTiming = switchTiming;
sc.min5.timing = timing;
sc.min5.xLabel = 'time (hours)';
sc.min5.yLabel = '5 min pixels fluorescence (a.u.)';
sc.min5.title = sprintf('Single cell Min5 - %s',gn);

% BG min 5
sc.BGmin5.condition = condition;
sc.BGmin5.switchTiming = switchTiming;
sc.BGmin5.timing = timing;
sc.BGmin5.xLabel = 'time (hours)';
sc.BGmin5.yLabel = '5 min pixels fluorescence (a.u.)';
sc.BGmin5.title = sprintf('Single cell BGmin5 - %s',gn);

% min sub
sc.minSub.condition = condition;
sc.minSub.switchTiming = switchTiming;
sc.minSub.timing = timing;
sc.minSub.xLabel = 'time (hours)';
sc.minSub.yLabel = 'single cell fluorescence (a.u.)';
sc.minSub.title = sprintf('Single cell minSub - %s',gn);

% BGmin sub
sc.BGminSub.condition = condition;
sc.BGminSub.switchTiming = switchTiming;
sc.BGminSub.timing = timing;
sc.BGminSub.xLabel = 'time (hours)';
sc.BGminSub.yLabel = 'single cell fluorescence (a.u.)';
sc.BGminSub.title = sprintf('Single cell BGminSub - %s',gn);

% min5 sub
sc.min5Sub.condition = condition;
sc.min5Sub.switchTiming = switchTiming;
sc.min5Sub.timing = timing;
sc.min5Sub.xLabel = 'time (hours)';
sc.min5Sub.yLabel = 'single cell fluorescence (a.u.)';
sc.min5Sub.title = sprintf('Single cell min5Sub - %s',gn);

% BGmin5 sub
sc.BGmin5Sub.condition = condition;
sc.BGmin5Sub.switchTiming = switchTiming;
sc.BGmin5Sub.timing = timing;
sc.BGmin5Sub.xLabel = 'time (hours)';
sc.BGmin5Sub.yLabel = 'single cell fluorescence (a.u.)';
sc.BGmin5Sub.title = sprintf('Single cell BGmin5Sub - %s',gn);

% 3 top pixels
sc.top3.condition = condition;
sc.top3.switchTiming = switchTiming;
sc.top3.timing = timing;
sc.top3.xLabel = 'time (hours)';
sc.top3.yLabel = '3 top pixels fluorescence (a.u.)';
sc.top3.title = sprintf('Single cell 3 top pixels - %s',gn);

% 5 top pixels
sc.top5.condition = condition;
sc.top5.switchTiming = switchTiming;
sc.top5.timing = timing;
sc.top5.xLabel = 'time (hours)';
sc.top5.yLabel = '5 top pixels fluorescence (a.u.)';
sc.top5.title = sprintf('Single cell 5 top pixels - %s',gn);

% 3 top pixels / median
sc.top3Med.condition = condition;
sc.top3Med.switchTiming = switchTiming;
sc.top3Med.timing = timing;
sc.top3Med.xLabel = 'time (hours)';
sc.top3Med.yLabel = '3 top pixels / median (a.u.)';
sc.top3Med.title = sprintf('Single cell punctate pattern - %s',gn);

% 5 top pixels / median
sc.top5Med.condition = condition;
sc.top5Med.switchTiming = switchTiming;
sc.top5Med.timing = timing;
sc.top5Med.xLabel = 'time (hours)';
sc.top5Med.yLabel = '5 top pixels / median (a.u.)';
sc.top5Med.title = sprintf('Single cell punctate pattern - %s',gn);

% cell count
sc.nbCell = nbCell;
sc.nbCell.condition = condition;
sc.nbCell.switchTiming = switchTiming;
sc.nbCell.timing = timing;
sc.nbCell.xLabel = 'time (hours)';
sc.nbCell.yLabel = 'cell number';
sc.nbCell.title = sprintf('Cell sorting summary - %s',gn);

clear selected all discarded out
save(fullfile(dataDir,sprintf('scData_%s_pos%d_%c.mat',expName,p,side)),'sc');


% Make summary plot
if showSummaryPlot == 1

    pngDir = fullfile(scMainDir,'summaryPlot');
    mkdir(pngDir);
    
    figure(11), clf;
    set(11,'Position',[0 0 1200 900]);
    set(gcf,'PaperPositionMode','auto');
    subplot(2,2,1), nd_scPlot(sc.area,summaryOption);
    subplot(2,2,2), nd_nbCellPlot(sc.nbCell,0);
    subplot(2,2,3), nd_scPlot(sc.water,summaryOption);
    subplot(2,2,4), nd_scPlot(sc.raw,summaryOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('summary_sorting_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('summary_Sorting_exp%d_pos%d_%c.png',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 1200 900]);
    set(gcf,'PaperPositionMode','auto');
    subplot(2,2,1), nd_scPlot(sc.min,summaryOption);
    subplot(2,2,2), nd_scPlot(sc.BGmin,summaryOption);
    subplot(2,2,3), nd_scPlot(sc.min5,summaryOption);
    subplot(2,2,4), nd_scPlot(sc.BGmin5,summaryOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('summary_BG_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('summary_BG_exp%d_pos%d_%c.png',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 1200 900]);
    set(gcf,'PaperPositionMode','auto');
    subplot(2,2,1), nd_scPlot(sc.minSub,summaryOption);
    subplot(2,2,2), nd_scPlot(sc.BGminSub,summaryOption);
    subplot(2,2,3), nd_scPlot(sc.min5Sub,summaryOption);
    subplot(2,2,4), nd_scPlot(sc.BGmin5Sub,summaryOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('summary_BGsub_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('summary_BGsub_exp%d_pos%d_%c.png',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 1200 900]);
    set(gcf,'PaperPositionMode','auto');
    subplot(2,2,1), nd_scPlot(sc.minSub,summaryOption);
    subplot(2,2,2), nd_scPlot(sc.min5Sub,summaryOption);
    subplot(2,2,3), nd_scPlot(sc.BGmin,3);
    subplot(2,2,4), hold on,
        textShift = [0.2 0.95];
        maxScale = 1.05;
        noise = sc.raw.std.^2 ./ sc.raw.mean.^2;
        noiseMin5 = sc.min5Sub.std.^2 ./ sc.min5Sub.mean.^2;
        noiseBGmin5 = sc.BGmin5Sub.std.^2 ./ sc.BGmin5Sub.mean.^2;
        noiseMin = sc.minSub.std.^2 ./ sc.minSub.mean.^2;
        noiseBGmin = sc.BGminSub.std.^2 ./ sc.BGminSub.mean.^2;
        yMax = max([noise noiseMin5 noiseBGmin5 noiseMin noiseBGmin]) * maxScale;
        plot(sc.raw.timing,noise,'r','LineWidth',2);
        plot(sc.raw.timing,noiseMin5,'g','LineWidth',2);
        plot(sc.raw.timing,noiseMin,'g:','LineWidth',2);
        plot(sc.raw.timing,noiseBGmin5,'b','LineWidth',2);
        plot(sc.raw.timing,noiseBGmin,'b:','LineWidth',2);
        for n = 2:Nswitch
            plot([sc.raw.switchTiming(n) sc.raw.switchTiming(n)],[0 yMax],':k','LineWidth',2);
            if strcmp(sc.raw.condition{n},'sc') == 0
                text(sc.raw.switchTiming(n)+textShift(1),textShift(2)*yMax,sc.raw.condition{n});
            end
        end
        axis([0 max(sc.raw.timing) 0 yMax]);
        xlabel('time (hours)','FontSize',12);
        ylabel('protein noise (\sigma^2/\mu^2)','FontSize',12);
        set(gca,'lineWidth',2,'FontSize',12);
        title(sprintf('noise - %s',gn),'FontSize',12);
        legend('Noise - raw','Noise - min5','Noise - min','Noise - BGmin5','Noise - BGmin','Location','Best');
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('summary_noise_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('summary_noise_exp%d_pos%d_%c.png',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 1200 900]);
    set(gcf,'PaperPositionMode','auto');
    subplot(2,2,1), nd_scPlot(sc.top3,summaryOption);
    subplot(2,2,2), nd_scPlot(sc.top5,summaryOption);
    subplot(2,2,3), nd_scPlot(sc.top3Med,summaryOption);
    subplot(2,2,4), nd_scPlot(sc.top5Med,summaryOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('summary_punctate_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('summary_punctate_exp%d_pos%d_%
    %c.png',s,p,side)));
    
end


% Make individual plots
if showIndividualPlot == 1
    
    pngDir = fullfile(scMainDir,'individualPlot');
    mkdir(pngDir);
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.area,individualOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('area_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('area_exp%d_pos%d_%c.eps',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_nbCellPlot(sc.nbCell,1);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('cellCount_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('cellCount_exp%d_pos%d_%c.eps',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.min5,individualOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('min_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('BG_exp%d_pos%d_%c.eps',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.water,individualOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('watershed_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('watershed_exp%d_pos%d_%c.eps',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.raw,individualOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('raw_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('raw_exp%d_pos%d_%c.eps',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.minSub,individualOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('minSub_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('BGsub_exp%d_pos%d_%c.eps',s,p,side)));
    
    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.top5,individualOption);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('5top_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('5top_exp%d_pos%d_%c.eps',s,p,side)));    

    figure(11), clf;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    nd_scPlot(sc.top5Med,3);
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('punctatePattern_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('punctatePattern_exp%d_pos%d_%c.eps',s,p,side)));    
    
    figure(11), clf, hold on;
    set(11,'Position',[0 0 800 600]);
    set(gcf,'PaperPositionMode','auto');
    textShift = [0.2 0.95];
    maxScale = 1.05;
    noise = sc.raw.std.^2 ./ sc.raw.mean.^2;
    noiseMin5 = sc.min5Sub.std.^2 ./ sc.min5Sub.mean.^2;
    noiseBGmin5 = sc.BGmin5Sub.std.^2 ./ sc.BGmin5Sub.mean.^2;
    noiseMin = sc.minSub.std.^2 ./ sc.minSub.mean.^2;
    noiseBGmin = sc.BGminSub.std.^2 ./ sc.BGminSub.mean.^2;
    yMax = max([noise noiseMin5 noiseBGmin5 noiseMin noiseBGmin]) * maxScale;
    plot(sc.raw.timing,noise,'r','LineWidth',2);
    plot(sc.raw.timing,noiseMin5,'g','LineWidth',2);
    plot(sc.raw.timing,noiseMin,'g:','LineWidth',2);
    plot(sc.raw.timing,noiseBGmin5,'b','LineWidth',2);
    plot(sc.raw.timing,noiseBGmin,'b:','LineWidth',2);
    for n = 2:Nswitch
        plot([sc.raw.switchTiming(n) sc.raw.switchTiming(n)],[0 yMax],':k','LineWidth',2);
        if strcmp(sc.raw.condition{n},'sc') == 0
            text(sc.raw.switchTiming(n)+textShift(1),textShift(2)*yMax,sc.raw.condition{n});
        end
    end
    axis([0 max(sc.raw.timing) 0 yMax]);
    xlabel('time (hours)','FontSize',12);
    ylabel('protein noise (\sigma^2/\mu^2)','FontSize',12);
    set(gca,'lineWidth',2,'FontSize',12);
    title(sprintf('noise - %s',gn),'FontSize',12);
    legend('Noise - raw','Noise - min5','Noise - min','Noise - BGmin5','Noise - BGmin','Location','Best');
    print(11,'-dpng',sprintf('-r%d',printDPI),fullfile(pngDir,sprintf('noise_%s_pos%d_%c.png',expName,p,side)));
    %print(11,'-depsc',fullfile(epsDir,sprintf('noise_exp%d_pos%d_%c.eps',s,p,side)));
    
end

cla
clear


